# Rocksmith 2014 Tab Converter
Homepage: http://www.rocksmithtotab.de

#### Summary
Exports Rocksmith 2014 arrangements to Guitar Pro tabs (.gp5, .gpx). It parses Rocksmith's .psarc archives and converts any songs found within to tablature. All the Rocksmith techniques are supported and translated, and you get all of the chord diagrams and fingering hints that Rocksmith shows you. It's a great way to figure out specific parts of a song, and Guitar Pro's speed trainer is a very good alternative to the riff repeater. All arrangement types (bass, lead, rhythm) can be exported, either together in a single tab or into separate tabs.
![gui][gui]

#### Current version
The current version is v1.1. Find it at http://www.rocksmithtotab.de .

#### Basic use

Download the appropriate version for your OS (Windows or Mac OSX) from the above link, then extract the archive to a location of your choice. If you are on Mac, you will also have to download and install the [Mono runtime environment (MRE)][mre]. On Windows, the program should work out of the box, but if you run into problems, you might need to install the [.NET Framework 4][dotnet].

If all you want to do is convert all the Rocksmith songs you own to tablature, then you can simply start the RocksmithToTabGUI.exe (or the RocksmithToTabGUI script on Mac), which will allow you to select your Rocksmith 2014 install directory and an output directory. If you then click on the "Convert tabs" button, it will convert all song arrangements that you own and save them in the select output folder.

For more advanced usage scenarios, including conversion of single arrangements, you will have to use the command line utility RocksmithToTab.exe (or the RocksmithToTab script on Mac). Open a command line, go to where you extracted the program and run
`RocksmithToTab \Path\To\Rocksmith2014\dlc\somefile.psarc`
which will convert all arrangements inside the archive somefile.psarc. Alternatively, if you do not like to use the command line, just drag and drop any .psarc file onto the RocksmithToTab.exe in the Windows explorer.

For more information, please refer to the [documentation][] and the [wiki][].

#### Command line options
For details, refer to the [wiki][].
```
Usage: RocksmithToTab archive.psarc [-a bass,lead] [-s song1,song2]

  -l, --list      List songs contained in the archive. No conversions are 
                  performed.

  -s, --songs     Comma-separated list of tracks to include. (default: all)

  -a, --arr       Comma-separated list of arrangements to include. (default: 
                  all)

  -t, --split     Create a separate file for each arrangement.

  -d, --diff      (Default: 255) Difficulty level. (default: max)

  -o, --outdir    (Default: .) Path to the directory where tabs should be 
                  created.

  -f, --format    (Default: gp5) File output format, currently either 'gp5', 
                  'gpx' or 'gpif'.
				  
  -n, --name	  (Default: {artist} - {title}) Format of the output file
				  names. For a list of available field names, refer to the
				  documentation.

  -x, --xml       Instead of a psarc archive, supply a number of XML files 
                  describing the arrangements.

  --help          Display this help screen.
```

#### Results
Some examples of output generated by the program:
![tab1][tab1]
![tab2][tab2]

#### Caveats
* As Rocksmith uses absolute timings and does not convey any rhythmic information, I have to make a lot of guesses to extrapolate the rhythmic durations of each note played. For the most part, this works quite decently, but do expect the occasional "weirdness", particularly in fast and "sloppy" solo passages. The program tries its best to approximate the absolute timings with rhythmic durations, but this may mean that it will sometimes mix up even and triplet notes that a human would not place.
* Guitar Pro 6 may or may not display more complicated bends correctly. Its predecessor, Guitar Pro 5, has much more sophisticated support for complex bends and should generally display the bends like they are in the game.
* The program by default lets every note ring until the next one, unless there's more than one silent bar. This means that notes might ring longer than they should. However, since Rocksmith doesn't have any information about pauses, I cannot do anything about it. If a note has a sustain value attached to it, I try my best to honor that sustain and let it ring for as long as it should and (ideally) not much longer.

#### Legal notice
Please do not share the generated tabs with anyone. The tabs are for your personal use only, and all rights remain with Ubisoft and the respective musicians.

#### Acknowledgements
Many thanks to the people at www.rscustom.net for creating the Rocksmith Custom Toolkit, without which this exporter would not have been possible. Likewise, I'd probably never have started this project if I didn't have the code from the [RSTabExplorer](https://github.com/andulv/RSTabExplorer) project as a starting point!

[tab1]: https://github.com/fholger/RocksmithToTab/blob/master/pics/sample1.jpg
[tab2]: https://github.com/fholger/RocksmithToTab/blob/master/pics/sample2.jpg
[gui]: https://github.com/fholger/RocksmithToTab/blob/master/pics/gui.jpg
[wiki]: https://github.com/fholger/RocksmithToTab/wiki/Options
[documentation]: http://www.rocksmithtotab.de/documentation/
[MacUserGuide]: https://github.com/fholger/RocksmithToTab/wiki/MacUserGuide
[mre]: http://www.mono-project.com/download/
[dotnet]: http://www.microsoft.com/en-us/download/details.aspx?id=17851